AppTransitions class

Constructors

AppTransitions()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildFadeTransition<T>(GoRouterState state, Widget child) Page<T>
淡入淡出
buildScaleTransition<T>(GoRouterState state, Widget child) Page<T>
缩放效果
buildSlideTransition<T>(GoRouterState state, Widget child) Page<T>
构建滑动过渡动画 state GoRouter 状态 child 子 Widget