EventBusUtils class

封装后的高级事件总线

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance → EventBus
获取单例实例
no setter

Static Methods

on<T>(void handler(T event), {bool handleError = true, ErrorCallback? onError}) StreamSubscription<T>
订阅事件,返回可取消的订阅对象
sendEvent<T>(T event) → void
发送事件