MediaPicker class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

chooseImage({int? imageQuality}) Future<String?>
选择照片 imageQuality 图片压缩质量,取值在0-100,越大返回图片的质量越高,默认为100,即原始图片
chooseMultiImage({int? limit, int? imageQuality}) Future<List<String>>
选择照片(多选) imageQuality 图片压缩质量,取值在0-100,越大返回图片的质量越高,默认为100,即原始图片
chooseMultiVideo({int? limit}) Future<List<String>>
选择视频(多选)
chooseVideo() Future<String?>
选择视频
takeImage({int? imageQuality}) Future<String?>
拍摄照片 imageQuality 图片压缩质量,取值在0-100,越大返回图片的质量越高,默认为100,即原始图片
takeVideo() Future<String?>
拍摄视频