ScreenAdapterUtils class

屏幕适配工具类,基于 flutter_screenutil 封装

Constructors

ScreenAdapterUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

init({required Widget child, int designWidth = 375, int designHeight = 812}) Widget
初始化屏幕适配