CachedImage class

Inheritance
Available extensions

Constructors

CachedImage({Key? key, required String? url, String? placeholderAssets = "packages/flutter_smart/assets/images/placeholder.png", String? errorAssets = "packages/flutter_smart/assets/images/placeholder.png", BoxFit? fit, double? width, double? height, BorderRadiusGeometry? borderRadius, double? borderRadiusAll, BoxBorder? border, dynamic onTap(String?)?})
const

Properties

border BoxBorder?
final
borderRadius BorderRadiusGeometry?
final
borderRadiusAll double?
final
errorAssets String?
final
fit BoxFit?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → dynamic Function(String?)?
final
placeholderAssets String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLongPress(void onLongPress()?) Widget

Available on Widget, provided by the ExtensionWidget extension

长按事件
onTap(void onTap()?) Widget

Available on Widget, provided by the ExtensionWidget extension

点击事件
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited