JsonUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
listToString(
List list) → String - 将 List 转换为 String
-
mapToList(
Map< String, dynamic> map) → List - 将 Map 转换为 List
-
mapToString(
Map< String, dynamic> map) → String - 将 Map 转换为 String
-
stringToList(
String str) → List - 将 String 转换为 List
-
stringToMap(
String str) → Map< String, dynamic> - 将 String 转换为 Map