TimeUtils class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- oneDayMillis ↔ int
-
一天的毫秒数:24小时 = 86400000毫秒
getter/setter pair
- oneHourMillis ↔ int
-
一小时的毫秒数:60分钟 = 3600000毫秒
getter/setter pair
- oneMinuteMillis ↔ int
-
一分钟的毫秒数:60秒 = 60000毫秒
getter/setter pair
- oneSecondMillis ↔ int
-
一秒的毫秒数:1000毫秒
getter/setter pair
Static Methods
-
currentTimeMillis(
) → int - 获取当前时间的毫秒时间戳
-
getWeekday(
DateTime? dateTime, {String languageCode = 'en', bool short = false}) → String - 获取指定日期的星期名称